@@ -1,4 +1,4 @@
-// Copyright 2024-2025 Andres Morey
+// Copyright 2024 The Kubetail Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -26,10 +26,14 @@ import (
 	"text/template"
 	"time"
 
+	"github.com/go-playground/validator/v10"
+	zlog "github.com/rs/zerolog/log"
 	"github.com/sosodev/duration"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
+	"github.com/spf13/viper"
 
+	"github.com/kubetail-org/kubetail/modules/shared/config"
 	"github.com/kubetail-org/kubetail/modules/shared/k8shelpers"
 	"github.com/kubetail-org/kubetail/modules/shared/logs"
 
@@ -37,6 +41,9 @@ import (
 	"github.com/kubetail-org/kubetail/modules/cli/internal/tablewriter"
 )
 
+var headFlag config.OptionalInt64
+var tailFlag config.OptionalInt64
+
 type logsStreamMode int
 
 const (
@@ -206,20 +213,46 @@ var logsCmd = &cobra.Command{
 			return fmt.Errorf("--force is required when using --grep")
 		}
 
+		var cli config.CLI
+		cli.Config, _ = flags.GetString("config")
+
+		if cli.Config != "" {
+			return validator.New().Struct(cli)
+		}
+
 		return nil
 	},
 	Run: func(cmd *cobra.Command, args []string) {
 		// Get flags
 		flags := cmd.Flags()
 
-		kubeContext, _ := flags.GetString(KubeContextFlag)
-		kubeconfigPath, _ := flags.GetString(KubeconfigFlag)
+		configPath, _ := cmd.Flags().GetString("config")
+		inCluster, _ := flags.GetBool(InClusterFlag)
+
+		v := viper.New()
+
+		v.BindPFlag("general.kubeconfig", cmd.Flags().Lookup(KubeconfigFlag))
+		v.BindPFlag("commands.logs.kube-context", cmd.Flags().Lookup(KubeContextFlag))
+		if headFlag.IsValueProvided {
+			v.Set("commands.logs.head", headFlag.Value)
+		}
+		if tailFlag.IsValueProvided {
+			v.Set("commands.logs.tail", tailFlag.Value)
+		}
+
+		cliCfg, err := config.NewCLIConfigFromViper(v, configPath)
+		if err != nil {
+			zlog.Fatal().Caller().Err(err).Send()
+		}
+		kubeContext := cliCfg.Commands.Logs.KubeContext
+		kubeconfigPath := cliCfg.General.KubeconfigPath
 
 		head := flags.Changed("head")
-		headVal, _ := flags.GetInt64("head")
+		headVal := cliCfg.Commands.Logs.Head
 
 		tail := flags.Changed("tail")
-		tailVal, _ := flags.GetInt64("tail")
+		tailVal := cliCfg.Commands.Logs.Tail
+
 		all, _ := flags.GetBool("all")
 		follow, _ := flags.GetBool("follow")
 
@@ -314,7 +347,11 @@ var logsCmd = &cobra.Command{
 		}
 
 		// Init connection manager
-		cm, err := k8shelpers.NewDesktopConnectionManager(k8shelpers.WithKubeconfigPath(kubeconfigPath), k8shelpers.WithLazyConnect(true))
+		env := config.EnvironmentDesktop
+		if inCluster {
+			env = config.EnvironmentCluster
+		}
+		cm, err := k8shelpers.NewConnectionManager(env, k8shelpers.WithKubeconfigPath(kubeconfigPath), k8shelpers.WithLazyConnect(true))
 		cli.ExitOnError(err)
 
 		// Init stream
@@ -619,10 +656,10 @@ func init() {
 	flagset.SortFlags = false
 
 	flagset.String(KubeContextFlag, "", "Specify the kubeconfig context to use")
-	flagset.Int64P("head", "h", 10, "Return first N records")
-	flagset.Lookup("head").NoOptDefVal = "10"
-	flagset.Int64P("tail", "t", 10, "Return last N records")
-	flagset.Lookup("tail").NoOptDefVal = "10"
+	flagset.VarP(&headFlag, "head", "h", "Return last N records (default 10)")
+	flagset.Lookup("head").NoOptDefVal = "N"
+	flagset.VarP(&tailFlag, "tail", "t", "Return last N records (default 10)")
+	flagset.Lookup("tail").NoOptDefVal = "N"
 	flagset.Bool("all", false, "Return all records")
 	logsCmd.MarkFlagsMutuallyExclusive("head", "tail", "all")
 
